Fix toolchain script

Make sure the llvm toolchain really pull from ToT. The original script
somehow only synced to a 2016 commit, and missed the RISCV target.

Change-Id: I63b276a8fe86f8112ac6941b46be4577913832fc
diff --git a/download-toolchain.sh b/download-toolchain.sh
index 909b97d..383758b 100755
--- a/download-toolchain.sh
+++ b/download-toolchain.sh
@@ -82,7 +82,7 @@
 fi
 popd > /dev/null
 
 # Download LLVM project if necessary. Always pull from master ToT.
 if [[ "${TOOLCHAIN_TARGET}" == "LLVM" ]]; then
   if [[ -d "${LLVM_SRC}" ]]; then
     echo "Removing existing ${LLVM_SRC}..."
@@ -92,7 +92,6 @@
   pushd "${LLVM_SRC}" > /dev/null
   git init
   git remote add origin https://github.com/llvm/llvm-project
-  git fetch origin --jobs=8 --depth=1
-  git reset --hard FETCH_HEAD
+  git pull origin main --jobs=8 --depth=1
   popd > /dev/null
 fi
@@ -82,7 +82,7 @@
 popd > /dev/null
 
-# Download LLVM project if necessary. Always pull from master ToT.
+# Download LLVM project if necessary. Always pull from main ToT.
 if [[ "${TOOLCHAIN_TARGET}" == "LLVM" ]]; then
   if [[ -d "${LLVM_SRC}" ]]; then